@@ -35,7 +35,7 @@ class NoteLike(events.basic.SimpleEvent):
         Fraction will also build :class:`mutwo.parameters.pitches.JustIntonationPitch`
         objects. Other numbers (integer and float) will be read as pitch class numbers
         to make :class:`mutwo.parameters.pitches.WesternPitch` objects.
-    :param new_duration: The duration of ``NoteLike``. This can be any number.
+    :param duration: The duration of ``NoteLike``. This can be any number.
         The unit of the duration is up to the interpretation of the user and the
         respective converter routine that will be used.
     :param volume: The volume of the event. Can either be a object of
@@ -52,11 +52,11 @@ class NoteLike(events.basic.SimpleEvent):
     :type grace_notes: events.basic.SequentialEvent[NoteLike]
     :param after_grace_notes:
     :type after_grace_notes: events.basic.SequentialEvent[NoteLike]
-    :param playing_indicators: A :class`~mutwo.parameters.playing_indicators.PlayingIndicatorCollection`.
+    :param playing_indicators: A :class:`~mutwo.parameters.playing_indicators.PlayingIndicatorCollection`.
         Playing indicators alter the sound of :class:`NoteLike` (e.g.
         tremolo, fermata, pizzicato).
     :type playing_indicators: parameters.playing_indicators.PlayingIndicatorCollection
-    :param notation_indicators: A :class`~mutwo.parameters.notation_indicators.NotationIndicatorCollection`.
+    :param notation_indicators: A :class:`~mutwo.parameters.notation_indicators.NotationIndicatorCollection`.
         Notation indicators alter the visual representation of :class:`NoteLike`
         (e.g. ottava, clefs) without affecting the resulting sound.
     :type notation_indicators: parameters.notation_indicators.NotationIndicatorCollection
@@ -156,7 +156,7 @@ class NoteLike(events.basic.SimpleEvent):
     @staticmethod
     def _convert_unknown_object_to_pitch(
         unknown_object: typing.Any,
-    ) -> typing.List[parameters.abc.Pitch]:
+    ) -> list[parameters.abc.Pitch]:
         if unknown_object is None:
             pitches = []
 
@@ -199,7 +199,7 @@ class NoteLike(events.basic.SimpleEvent):
     # ###################################################################### #
 
     @property
-    def _parameters_to_print(self) -> typing.Tuple[str, ...]:
+    def _parameters_to_print(self) -> tuple[str, ...]:
         """Return tuple of attribute names which shall be printed for repr."""
         return tuple(
             attribute
